@@ -92,4 +92,12 @@ setMethod("as.data.frame", signature(x = "Nri"),
     nri_data <- nri_data[,rem]
   }
   return(nri_data)
-})
\ No newline at end of file
+})
+
+setMethod("dim", signature(x = "Nri"), 
+                 definition = function(x)
+{
+  dimX <- dim(x@nri)
+  return(dimX)
+}
+)
\ No newline at end of file
